@@ -31,8 +31,8 @@ public:
 
 protected:
     QString mStatus;
-    ConnectionsModel *m_connections;
-    NetstatHelper *m_netstatHelper;
+    ConnectionsModel *const m_connections;
+    NetstatHelper *m_netstatHelper = nullptr;
 
     /* Netstat has been deprecated for more than 20 years,
      * let's discourage distros using it as default.
